#[repr(u8)]pub enum Mstslvcfg {
NORMAL_SLAVE_MODE = 0,
WS_SYNC_MASTER = 1,
MASTER_USING_SCK = 2,
NORMAL_MASTER = 3,
}Variants
NORMAL_SLAVE_MODE = 0
Normal slave mode, the default mode. SCK and WS are received from a master and used to transmit or receive data.
WS_SYNC_MASTER = 1
WS synchronized master. WS is received from another master and used to synchronize the generation of SCK, when divided from the Flexcomm function clock.
MASTER_USING_SCK = 2
Master using an existing SCK. SCK is received and used directly to generate WS, as well as transmitting or receiving data.
NORMAL_MASTER = 3
Normal master mode. SCK and WS are generated so they can be sent to one or more slave devices.
Implementations